@@ -95,7 +95,6 @@ class PreferencesWindow(Setting_Ui):
         else:
             self.remote_time_checkBox.setChecked(False)
 
-
         # add support for other languages
         locale = str(self.persepolis_setting.value('settings/locale'))
         QLocale.setDefault(QLocale(locale))
@@ -118,7 +117,7 @@ class PreferencesWindow(Setting_Ui):
         aria2_path = self.persepolis_setting.value('settings/aria2_path')
 
         self.aria2_path_lineEdit.setEnabled(False)
-        if aria2_path != None:
+        if aria2_path is not None:
             self.aria2_path_checkBox.setChecked(True)
             self.aria2_path_lineEdit.setText(str(aria2_path))
 
@@ -165,7 +164,7 @@ class PreferencesWindow(Setting_Ui):
             self.style_comboBox.setCurrentIndex(current_style_index)
 
         # available language
-        available_language = ['en_US', 'fa_IR','ar', 'es_ES', 'fr_FR', 'ko', 'pl_PL', 'pt', 'ru', 'tr', 'zh_CN', 'de', 'hu', 'nl_NL', 'pt_BR', 'sv', 'tr_TR', 'zh_TW']
+        available_language = ['en_US', 'fa_IR', 'ar', 'es_ES', 'fr_FR', 'ko', 'pl_PL', 'pt', 'ru', 'tr', 'zh_CN', 'de', 'hu', 'nl_NL', 'pt_BR', 'sv', 'tr_TR', 'zh_TW']
         for lang in available_language:
             self.lang_comboBox.addItem(str(QLocale(lang).nativeLanguageName()), lang)
 
@@ -289,6 +288,12 @@ class PreferencesWindow(Setting_Ui):
         else:
             self.keep_awake_checkBox.setChecked(False)
 
+        # check_clipboard_checkBox
+        if str(self.persepolis_setting.value('check-clipboard')) == 'yes':
+            self.check_clipboard_checkBox.setChecked(True)
+        else:
+            self.check_clipboard_checkBox.setChecked(False)
+
         # columns_tab
         if str(self.persepolis_setting.value('column0')) == 'yes':
             self.column0_checkBox.setChecked(True)
@@ -404,7 +409,6 @@ class PreferencesWindow(Setting_Ui):
         for member in self.persepolis_setting.allKeys():
             self.first_key_value_dict[member] = str(self.persepolis_setting.value(member))
 
-
         # if style_comboBox is changed, self.styleComboBoxChanged is called.
         self.style_comboBox.currentIndexChanged.connect(self.styleComboBoxChanged)
 
@@ -423,8 +427,8 @@ class PreferencesWindow(Setting_Ui):
         self.resize(size)
         self.move(position)
 
-
     # run this method if user doubleclicks on an item in shortcut_table
+
     def showCaptureKeyboardWindow(self):
 
         # show KeyCapturingWindow
@@ -435,7 +439,7 @@ class PreferencesWindow(Setting_Ui):
 
     def callBack(self, keys):
         # do nothing if keys is empty
-        if not(keys):
+        if not (keys):
             return
 
         # check that if shortcut used before.
@@ -444,7 +448,6 @@ class PreferencesWindow(Setting_Ui):
             self.msgBox.setText(QCoreApplication.translate("setting_src_ui_tr", "<b><center>This shortcut has been used before!\
                     Use another one!</center></b>"))
             self.msgBox.setIcon(QMessageBox.Warning)
-            reply = self.msgBox.exec_()
 
         # set new shortcut
         else:
@@ -487,7 +490,7 @@ class PreferencesWindow(Setting_Ui):
             self.color_comboBox.setEnabled(True)
 
             # color_comboBox items
-            color_scheme = ['Dark Fusion', 'Light Fusion'] 
+            color_scheme = ['Dark Fusion', 'Light Fusion']
 
             # add items
             self.color_comboBox.addItems(color_scheme)
@@ -531,14 +534,14 @@ class PreferencesWindow(Setting_Ui):
         elif selected_style == 'Adwaita' or selected_style == 'macintosh':
             dark_theme = False
 
-        if dark_theme == True:
+        if dark_theme is True:
             self.icon_comboBox.clear()
 
             if selected_size < 48:
                 icons = ['Breeze-Dark', 'Papirus-Dark']
             else:
                 icons = ['Breeze-Dark']
- 
+
             self.icon_comboBox.addItems(icons)
 
             # current_icons_index is -1, if findText couldn't find icon index.
@@ -550,14 +553,13 @@ class PreferencesWindow(Setting_Ui):
 
             self.icon_comboBox.setCurrentIndex(current_icons_index)
 
-        elif dark_theme == False:
+        elif dark_theme is False:
 
             if selected_size < 48:
                 icons = ['Breeze', 'Papirus', 'Papirus-Light']
             else:
                 icons = ['Breeze', 'Papirus']
 
-
             self.icon_comboBox.addItems(icons)
 
             # current_icons_index is -1, if findText couldn't find icon index.
@@ -569,14 +571,13 @@ class PreferencesWindow(Setting_Ui):
 
             self.icon_comboBox.setCurrentIndex(current_icons_index)
 
-
         else:
             if selected_size < 48:
                 icons = ['Breeze', 'Breeze-Dark', 'Papirus',
-                        'Papirus-Dark', 'Papirus-Light']
+                         'Papirus-Dark', 'Papirus-Light']
             else:
                 icons = ['Breeze', 'Breeze-Dark', 'Papirus']
- 
+
             self.icon_comboBox.addItems(icons)
 
             # current_icons_index is -1, if findText couldn't find icon index.
@@ -588,7 +589,6 @@ class PreferencesWindow(Setting_Ui):
 
             self.icon_comboBox.setCurrentIndex(current_icons_index)
 
-
     def fontCheckBoxState(self, checkBox):
 
         # deactivate fontComboBox and font_size_spinBox if font_checkBox not checked!
@@ -604,7 +604,6 @@ class PreferencesWindow(Setting_Ui):
         if event.key() == Qt.Key_Escape:
             self.close()
 
-
     def closeEvent(self, event):
 
         # saving window size and position
@@ -614,7 +613,7 @@ class PreferencesWindow(Setting_Ui):
         self.persepolis_setting.sync()
         event.accept()
 
-        if self.parent.isVisible() == False:
+        if self.parent.isVisible() is False:
             self.parent.minMaxTray(event)
         self.close()
 
@@ -690,7 +689,7 @@ class PreferencesWindow(Setting_Ui):
         # dont_check_certificate_checkBox
         self.dont_check_certificate_checkBox.setChecked(False)
 
-        # uncheck remote time 
+        # uncheck remote time
         self.remote_time_checkBox.setChecked(False)
 
         # save_as_tab
@@ -775,6 +774,9 @@ class PreferencesWindow(Setting_Ui):
         # keep_awake_checkBox
         self.keep_awake_checkBox.setChecked(False)
 
+        # check clipboard
+        self.check_clipboard_checkBox.setChecked(False)
+
         # columns_tab
         self.column0_checkBox.setChecked(True)
         self.column1_checkBox.setChecked(True)
@@ -850,14 +852,12 @@ class PreferencesWindow(Setting_Ui):
         else:
             self.persepolis_setting.setValue('dont-check-certificate', 'no')
 
-        # remote time 
+        # remote time
         if self.remote_time_checkBox.isChecked():
             self.persepolis_setting.setValue('remote-time', 'yes')
         else:
             self.persepolis_setting.setValue('remote-time', 'no')
 
-
-
         # changing icons
 
         icons = self.icon_comboBox.currentText()
@@ -975,7 +975,7 @@ class PreferencesWindow(Setting_Ui):
         if self.startup_checkbox.isChecked():
             self.persepolis_setting.setValue('startup', 'yes')
 
-            if not(startup.checkStartUp()):  # checking existence of Persepolis in  system's startup
+            if not (startup.checkStartUp()):  # checking existence of Persepolis in  system's startup
 
                 startup.addStartUp(self.parent)  # adding Persepolis to system's startup
         else:
@@ -993,6 +993,12 @@ class PreferencesWindow(Setting_Ui):
             self.persepolis_setting.setValue('awake', 'no')
             self.parent.keep_awake_checkBox.setChecked(False)
 
+        # check_clipboard_checkBox
+        if self.check_clipboard_checkBox.isChecked():
+            self.persepolis_setting.setValue('check-clipboard', 'yes')
+        else:
+            self.persepolis_setting.setValue('check-clipboard', 'no')
+
         # this section  creates download folder and
         # download sub folders if they did not existed.
 
@@ -1160,7 +1166,12 @@ class PreferencesWindow(Setting_Ui):
         show_message_box = False
         for key in self.first_key_value_dict.keys():
             if self.first_key_value_dict[key] != self.second_key_value_dict[key]:
-                if key in ['locale', 'aria2_path', 'download_path', 'custom-font', 'rpc-port', 'max-tries', 'retry-wait', 'timeout', 'connections', 'style', 'font', 'font-size', 'color-scheme']:
+                if key in ['locale', 'aria2_path', 'download_path',
+                           'custom-font', 'rpc-port', 'max-tries',
+                           'retry-wait', 'timeout', 'connections',
+                           'style', 'font', 'font-size', 'color-scheme',
+                           'check-clipboard']:
+
                     show_message_box = True
 
         # if any thing changed that needs restarting, then notify user about "Some changes take effect after restarting persepolis"
